# load libraries

setwd("SET YOUR PATH")


library("foreign")
library("Hmisc")
library("plm")
library("lme4")
library("plyr")
library("ggplot2")
library("ggthemes")
library("gridExtra")


mydata <- read.dta("figures/Figure3.dta")
summary(mydata)




mydata$depvar<-factor(mydata$depvar, labels = c("Sales", "Customers", "Market share", "Profitability"))
mydata$model<-factor(mydata$model, labels = c("With skewness and sample correction", "With sample correction"))

limits_g <- aes(ymax = high_g, ymin=low_g)
limits_r <- aes(ymax = high_r, ymin=low_r)


fig2a <- ggplot(mydata, aes( x = depvar, y = b_g, group=model, shape=model)) + theme_bw() + 
		geom_errorbar(aes(x=depvar, ymin=low_g, ymax=high_g),
			 width=0.2, size=0.2, color="gray36", position=position_dodge(width=0.4)) +
		geom_point(size=4,position=position_dodge(width=0.4)) +
		geom_hline(aes(yintercept=0), color="#D55E00", size=0.3) +
			 ylab("") + xlab("") +
		coord_flip() + theme(plot.title = element_text(hjust = 0.5)) +
		theme(legend.position="bottom") + theme(legend.title = element_blank()) + 
		theme(axis.text.y = element_text(size=rel(1.2), color="black"), axis.text.x = element_text(size=rel(1.2), color="black")
			, axis.title.x = element_text(size=rel(1.2))) + 
		ggtitle("Predicted effects of Gender Diversity")	
fig2a


fig2b <- ggplot(mydata, aes( x = depvar, y = b_r, group=model, shape=model)) + theme_bw() +
		geom_errorbar(aes(x=depvar, ymin=low_r, ymax=high_r),
			 width=0.2, size=0.2, color="gray36", position=position_dodge(width=0.4)) +
		geom_point(size=4,position=position_dodge(width=0.4)) +
		geom_hline(aes(yintercept=0), color="#D55E00", size=0.3) +
			 ylab("") + xlab("") +
		coord_flip() + theme(plot.title = element_text(hjust = 0.5)) +
				theme(legend.position="bottom") + theme(legend.title = element_blank()) + 
		theme(axis.text.y = element_text(size=rel(1.2), color="black"), axis.text.x = element_text(size=rel(1.2), color="black") 
			, axis.title.x = element_text(size=rel(1.2)))	+
		ggtitle("Predicted effects of Racial Diversity")	


fig2b


 fig2 <- grid.arrange(fig2a, fig2b, nrow=1)
  print(fig2)
ggsave(file="figures/Figure3.tiff", plot=fig2, dpi=300, width=16, height=8)


