*==============================================================================*
*                              Description of dofile                           *
/*=============================================================================*
This dofile generates Table 1 as presented in the comment "Does Diversity Pay? 
A Replication of Herring (2009)." The structure of this dofile is as follows:
      
  
  1. Setting paths 
  2. Missing values and sample sizes (Table 1)

*==============================================================================*/
*    	   	  	 			 1. Setting paths         			               *
*==============================================================================*

** -- A. Setting paths -- **
global dir "SET YOUR PATH"

global pathd "$dir/data"
global pathp "$dir/posted"
global patht "$dir/tables"
global pathf "$dir/figures"
global pathl "$dir/logfiles"


cap log close
log using "$pathl/analyses_missing.log", replace

*==============================================================================*
*                  2. Missing values and sample sizes    	                   *
*==============================================================================*

/*Table 1. Missing Data in the NOS 1996/7 for the Four Dependent Variables

The information in the table is derived from the routine below.*/



//SALES//
use "$pathp/nos_workingdata.dta", clear

	/*selecting only forprofit organizations*/
	keep if forprofit==1 //cases lost: 292
	distinct orgid //cases left: 710

	/*missing data on outcome*/
	recode o9 -999=. 
	keep if !missing(o9) //cases lost: 58
	distinct orgid //cases left: 652
	recode o9 88888888888=. 
	keep if !missing(o9) //cases lost: 206
	distinct orgid //cases left: 446
	recode o9 99999999999=.
	keep if !missing(o9) //cases lost: 64
	distinct orgid //cases left: 382
	
	/*missing data on diversity indicators*/
	keep if !missing(aidr)& !missing(aidg) //cases lost: 55
	distinct orgid //cases left: 327

	/*missing data on control variables*/
	keep if !missing(proprietorship) & !missing(partnership) & !missing(public_corporation) ///
	& !missing(private_corporation) & !missing(company_size) & !missing(establishment_size) ///
	& !missing(organization_age) & !missing(agriculture) & !missing(mining) & !missing(construction) ///
	& !missing(transportation) & !missing(wholesale) & !missing(retail) & !missing(financialserv) ///
	& !missing(businessserv) & !missing(personalserv) & !missing(entertainment) & !missing(professionalserv) ///
	& !missing(northeast) & !missing(midwest) & !missing(south) //cases lost: 88
	distinct orgid //cases left: 239
	
//CUSTOMERS//
use "$pathp/nos_workingdata.dta", clear

	/*selecting only forprofit organizations*/
	keep if forprofit==1 //cases lost: 292
	distinct orgid //cases left: 710

	/*missing data on outcome*/
	recode o8 -999=. 
	keep if !missing(o8) //cases lost: 60
	distinct orgid //cases left: 650
	recode o8 88888888=. 
	keep if !missing(o8) //cases lost: 224
	distinct orgid //cases left: 426
	recode o8 99999999=.
	keep if !missing(o8) //cases lost: 7
	distinct orgid //cases left: 419
	
	/*missing data on diversity indicators*/
	keep if !missing(aidr)& !missing(aidg) //cases lost: 55
	distinct orgid //cases left: 364

	/*missing data on control variables*/
	keep if !missing(proprietorship) & !missing(partnership) & !missing(public_corporation) ///
	& !missing(private_corporation) & !missing(company_size) & !missing(establishment_size) ///
	& !missing(organization_age) & !missing(agriculture) & !missing(mining) & !missing(construction) ///
	& !missing(transportation) & !missing(wholesale) & !missing(retail) & !missing(financialserv) ///
	& !missing(businessserv) & !missing(personalserv) & !missing(entertainment) & !missing(professionalserv) ///
	& !missing(northeast) & !missing(midwest) & !missing(south) //cases lost: 94
	distinct orgid //cases left: 270
	
	/*dropping organizations with 0 customers*/
	keep if customers>0 //cases lost: 4
	distinct orgid //cases left: 266

//MARKET SHARE//
use "$pathp/nos_workingdata.dta", clear

	/*selecting only forprofit organizations*/
	keep if forprofit==1 //cases lost: 292
	distinct orgid //cases left: 710

	/*missing data on outcome*/
	recode o10b -999=. 
	keep if !missing(o10b) //cases lost: 42
	distinct orgid //cases left: 668
	recode o10b 6=. 
	keep if !missing(o10b) //cases lost: 66
	distinct orgid //cases left: 602
	recode o10b 7=.
	keep if !missing(o10b) //cases lost: 9
	distinct orgid //cases left: 593
	
	/*missing data on diversity indicators*/
	keep if !missing(aidr)& !missing(aidg) //cases lost: 100
	distinct orgid //cases left: 493

	/*missing data on control variables*/
	keep if !missing(proprietorship) & !missing(partnership) & !missing(public_corporation) ///
	& !missing(private_corporation) & !missing(company_size) & !missing(establishment_size) ///
	& !missing(organization_age) & !missing(agriculture) & !missing(mining) & !missing(construction) ///
	& !missing(transportation) & !missing(wholesale) & !missing(retail) & !missing(financialserv) ///
	& !missing(businessserv) & !missing(personalserv) & !missing(entertainment) & !missing(professionalserv) ///
	& !missing(northeast) & !missing(midwest) & !missing(south) //cases lost: 145
	distinct orgid //cases left: 348
	
/*PROFITABILITY*/
use "$pathp/nos_workingdata.dta", clear

	/*selecting only forprofit organizations*/
	keep if forprofit==1 //cases lost: 292
	distinct orgid //cases left: 710

	/*missing data on outcome*/
	recode o10a -999=. 
	keep if !missing(o10a) //cases lost: 41
	distinct orgid //cases left: 669
	recode o10a 6=. 
	keep if !missing(o10a) //cases lost: 49
	distinct orgid //cases left: 620
	recode o10a 7=.
	keep if !missing(o10a) //cases lost: 8
	distinct orgid //cases left: 612
	
	/*missing data on diversity indicators*/
	keep if !missing(aidr)& !missing(aidg) //cases lost: 102
	distinct orgid //cases left: 510

	/*missing data on control variables*/
	keep if !missing(proprietorship) & !missing(partnership) & !missing(public_corporation) ///
	& !missing(private_corporation) & !missing(company_size) & !missing(establishment_size) ///
	& !missing(organization_age) & !missing(agriculture) & !missing(mining) & !missing(construction) ///
	& !missing(transportation) & !missing(wholesale) & !missing(retail) & !missing(financialserv) ///
	& !missing(businessserv) & !missing(personalserv) & !missing(entertainment) & !missing(professionalserv) ///
	& !missing(northeast) & !missing(midwest) & !missing(south) //cases lost: 148
	distinct orgid //cases left: 362

	
log close	
